@@ -1,7 +1,10 @@
 use tokio::io::{AsyncRead, AsyncWrite};
 
 use crate::client::inner::Inner;
-use crate::proto::command::{Command, CommandLogin};
+use crate::proto::{
+    bytes::Bytes,
+    command::{Command, CommandLogin},
+};
 
 pub trait Client: AsyncRead + AsyncWrite + Unpin + Sync + Send + 'static {}
 
@@ -24,8 +27,8 @@ impl AuthMethod for Login {
         C: Client,
     {
         let command = Command::Login(CommandLogin {
-            username: &self.username,
-            password: &self.password,
+            username: Bytes::from(self.username.clone()),
+            password: Bytes::from(self.password.clone()),
         });
 
         let _result = inner.execute(command).await;
