@@ -1,17 +1,16 @@
-// #[macro_use]
+#[macro_use]
 extern crate anyhow;
 #[macro_use]
 extern crate async_trait;
-// #[macro_use]
+#[macro_use]
 extern crate log;
 #[macro_use]
 extern crate futures;
 #[macro_use]
 extern crate derive_builder;
-#[macro_use]
-extern crate bitflags;
+// #[macro_use]
+// extern crate bitflags;
 
 pub mod client;
-pub mod codec;
-pub mod events;
+// pub mod events;
 pub mod proto;
