@@ -1,6 +1,6 @@
 macro_rules! rule {
     ($vis:vis $name:ident : $ret:ty => $expr:expr) => {
-        $vis fn $name(i: &[u8]) -> nom::IResult<&[u8], $ret> {
+        $vis fn $name(i: crate::proto::bytes::Bytes) -> nom::IResult<crate::proto::bytes::Bytes, $ret> {
             $expr(i)
         }
     };
