@@ -1,17 +1,22 @@
+//! Helper functions for manipulating the wire protocol.
+
 #![allow(non_snake_case, dead_code)]
 
+// utils
 #[macro_use]
 mod macros;
+pub mod bytes;
+#[macro_use]
+pub mod parsers;
 
 // data types
 pub mod command;
 pub mod response;
 
 // parsers
-#[macro_use]
-pub mod parsers;
 pub mod rfc2234;
 pub mod rfc3501;
+pub mod rfc6154;
 
-#[cfg(feature = "rfc2177-idle")]
+#[cfg(feature = "rfc2177")]
 pub mod rfc2177;
