@@ -1,6 +1,9 @@
+//! ABNF Core Rules
+//! ---
+//!
 //! Grammar from <https://tools.ietf.org/html/rfc2234#section-6.1>
 
-use nom::{branch::alt, character::streaming::anychar, multi::many0, sequence::pair};
+use nom::{branch::alt, multi::many0, sequence::pair};
 
 use super::parsers::{byte, satisfy, skip};
 
@@ -16,10 +19,10 @@ rule!(pub CR : u8 => satisfy(is_cr));
 
 rule!(pub CRLF : (u8, u8) => pair(CR, LF));
 
-pub fn is_ctl(c: u8) -> bool { c <= b'\x1f' || c == b'\x7f' }
+pub(crate) fn is_ctl(c: u8) -> bool { c <= b'\x1f' || c == b'\x7f' }
 rule!(pub CTL : u8 => satisfy(is_ctl));
 
-pub fn is_digit(c: u8) -> bool { c >= b'\x30' && c <= b'\x39' }
+pub(crate) fn is_digit(c: u8) -> bool { c >= b'\x30' && c <= b'\x39' }
 rule!(pub DIGIT : u8 => satisfy(is_digit));
 
 pub(crate) fn is_dquote(c: u8) -> bool { c == b'\x22' }
@@ -34,7 +37,7 @@ rule!(pub LF : u8 => satisfy(is_lf));
 
 rule!(pub LWSP : () => skip(many0(alt((skip(WSP), skip(pair(CRLF, WSP)))))));
 
-rule!(pub OCTET : char => anychar);
+// rule!(pub OCTET : char => anychar);
 
 pub(crate) fn is_sp(c: u8) -> bool { c == b'\x20' }
 rule!(pub SP : u8 => satisfy(is_sp));
